==> htsct-0.0.22-py3-none-any.whl: htsct/cli/init.py <==
from argparse import ArgumentParser
from htsct.constants import HTS_HOME, HTS_STATICS
from os import mkdir
from importlib.resources import open_binary
from toml import load, dump


class CLICommand:
    """初始化配置文件，设置环境变量

    说明：
        1.在$HOME下导出.htsct.toml配置文件
    """

    @staticmethod
    def add_argments(parser: ArgumentParser):
        pass

    @staticmethod
    def run(args, parser):
        copy_statics()
        data = load(HTS_HOME / ".htsct.toml")
        data['vasp']['vasp_std'] = input(f"请输入vasp_std执行路径(默认:{data['vasp']['vasp_std']})\n:") or data['vasp'][
            'vasp_std']
        data['vasp']['vasp_ncl'] = input(f"请输入vasp_ncl执行路径(默认:{data['vasp']['vasp_ncl']})\n:") or data['vasp'][
            'vasp_ncl']
        data['vasp']['vasp_gam'] = input(f"请输入vasp_gam执行路径(默认:{data['vasp']['vasp_gam']})\n:") or data['vasp'][
            'vasp_gam']
        data['scripts']['qsub'] = input(f"请输入qsub脚本路径(默认:{data['scripts']['qsub']})\n:") or data['scripts']['qsub']
        data['output']['task_log'] = input(f"请输入task_log任务日志路径(默认:{data['output']['task_log']})\n:") or data['output'][
            'task_log']
        data['output']['figs_path'] = input(f"请输入figs_path图片保存路径(默认:{data['output']['figs_path']})\n:") or \
                                      data['output']['figs_path']
        data['output']['db_dir'] = input(f"请输入qsub脚本路径(默认:{data['output']['db_dir']})\n:") or data['output']['db_dir']
        data['output']['work_path'] = input(f"请输入qsub脚本路径(默认:{data['output']['work_path']})\n:") or data['output'][
            'work_path']
        data['output']['wait_interval'] = input(f"请输入qsub脚本路径(默认:{data['output']['wait_interval']})\n:") or \
                                          data['output']['wait_interval']
        with open(HTS_HOME / ".htsct.toml", "w+", encoding="utf-8") as fd:
            dump(data, fd)


def copy_statics():
    print("Start initialize...")
    if not HTS_HOME.is_dir():
        mkdir(HTS_HOME)
    static_pkg, statics = HTS_STATICS
    for static in statics:
        data = open_binary(static_pkg, static).read()
        with open(HTS_HOME / static, "wb+") as fd:
            print(f"Copy '{static_pkg}/{static}' to '{HTS_HOME}'", end=" ... ")
            fd.write(data)
            print("done")

==> htsct-0.0.27-py3-none-any.whl: htsct/cli/init.py <==
from argparse import ArgumentParser
from htsct.constants import HTS_HOME, HTS_STATICS
from os import mkdir
from importlib.resources import open_binary
from toml import load, dump


class CLICommand:
    """初始化配置文件，设置环境变量

    说明：
        1.在$HOME下导出.htsct.toml配置文件
    """

    @staticmethod
    def add_argments(parser: ArgumentParser):
        pass

    @staticmethod
    def run(args, parser):
        copy_statics()
        data = load(HTS_HOME / ".htsct.toml")
        data['vasp']['vasp_std'] = input(f"请输入vasp_std执行路径(默认:{data['vasp']['vasp_std']})\n:") or data['vasp'][
            'vasp_std']
        data['vasp']['vasp_ncl'] = input(f"请输入vasp_ncl执行路径(默认:{data['vasp']['vasp_ncl']})\n:") or data['vasp'][
            'vasp_ncl']
        data['vasp']['vasp_gam'] = input(f"请输入vasp_gam执行路径(默认:{data['vasp']['vasp_gam']})\n:") or data['vasp'][
            'vasp_gam']
        data['scripts']['qsub'] = input(f"请输入qsub脚本路径(默认:{data['scripts']['qsub']})\n:") or data['scripts']['qsub']
        data['output']['task_log'] = input(f"请输入task_log任务日志路径(默认:{data['output']['task_log']})\n:") or data['output'][
            'task_log']
        data['output']['figs_path'] = input(f"请输入figs_path图片保存路径(默认:{data['output']['figs_path']})\n:") or \
                                      data['output']['figs_path']
        data['output']['db_dir'] = input(f"请输入数据库保存路径(默认:{data['output']['db_dir']})\n:") or data['output']['db_dir']
        data['output']['work_path'] = input(f"请输入工作路径路径(默认:{data['output']['work_path']})\n:") or data['output'][
            'work_path']
        data['output']['wait_interval'] = input(f"请输入等待时间间隔(默认:{data['output']['wait_interval']})\n:") or \
                                          data['output']['wait_interval']
        with open(HTS_HOME / ".htsct.toml", "w+", encoding="utf-8") as fd:
            dump(data, fd)


def copy_statics():
    print("Start initialize...")
    if not HTS_HOME.is_dir():
        mkdir(HTS_HOME)
    static_pkg, statics = HTS_STATICS
    for static in statics:
        data = open_binary(static_pkg, static).read()
        with open(HTS_HOME / static, "wb+") as fd:
            print(f"Copy '{static_pkg}/{static}' to '{HTS_HOME}'", end=" ... ")
            fd.write(data)
            print("done")
